# Apply Account Security Resources via CI/CD CodePipeline - Deployment Guide

## 1. Introduction

The purpose of this document is to describe the deployment procedure for the solution and its parameters

This setup assume you have one account to act as Parent Security Account, all other accounts in organization are referred as child account including one central logging account.

For example
111111111111 -> One of the child account
222222222222 -> Another child account as well as Central Logging Account
333333333333 -> Parent Security Account


## 2. Deployment procedure 

### NOTE : Launch all the Initial templates in US-EAST-1

Step 1: Create the required IAM permissions in all the target child accounts, the parent security account and central logging account by deploying a CloudFormation stack using the template named `Childaccount_IAM_role_All_Accounts.yaml` within the `/templates/initial_deployment_templates` directory of the package. Make sure that the name of the IAM role that is passed as a paramater is consistent across all the accounts. 

Step 2: In the Central Logging account, launch the template "S3Buckets-Centralized-LoggingAccount.yaml" within the `/templates/initial_deployment_templates` directory of the package, to create the S3 buckets which will be used to store all the logs, templates and s3 access logs at a centralized location. Make note of the all the S3 bucket names as it will be used in Step6 to modify the parameters file.

Step3: In the Parent Security Account, deploy the CI/CD Pipeline using the template `security-guard-rails-codepipeline-Centralized-SecurityAccount.yml` within the `/templates/initial_deployment_templates` directory of the package. Using this Pipeline all the infrastructure will be deployed in all the child accounts.

Step 4: Modify the file `Accountlist.json` which is at the top level in the package with the parent account number and the child account numbers:

```JSON
{   "ParentAccount": "<Parent-Security-Account-Number>",
    "ChildAccountList": ["Parent-Security-Account-Number",Account-A-Number","Account-B-Number", .....],
    "TargetRegion": ["us-east-1","us-west-2",.....]
}

example:
{   "ParentAccount": "333333333333",
    "ChildAccountList": ["333333333333","111111111111","222222222222"],
    "TargetRegion": ["us-east-1","us-west-2"]
}
```

Step 5: Modify `accounts.csv` which is in the parent folder. Add all the child accounts along with the email registered with the accounts in the format shown below. 

`NOTE:DO NOT INCLUDE PARENT SECURITY ACCOUNT IN THIS LIST`

```
Accounts,
111111111111,user1@email.com
222222222222,user2@email.com
```

Step 6: Modify `parameters.config` file which is located in the /templates folder. There are multiple parameters but you can leave all the parameters as default except the one highlighted below

```

pNotifyEmail="myemail@xyz.com" -> email id you subscribed while building code pipeline also
pstackNameLogging="logging-parent-stack" -> Name of the Cloudformation Stack for logging
pS3LogsBucket=“myaccount-central-logs-bucket” -> Centralized bucket in Logging account where logs from all the accounts will be stored. Get the bucket name from the S3 bucket name used in step2.
pTemplateBucketName="myaccount-central-cfn-templates" ->  Centralized bucket account where templates are stored. Get the bucket name from the S3 bucket name used in step2.
pAllowedAccounts = "111111111111,222222222222,333333333333" -> update with all the account ids, Parent and child accounts. Get the bucket name from the S3 bucket name used in step2.
pBucketName = arn:aws:s3:::myaccount-central-logs-bucket -> s3 Arn for the Centralized bucket used to store logs

Other parameters are optional and can be left to default settings
```

Step 7 :From the outputs section of the CI/CD infrastructure, note down the name of the CodeCommit repository url and create and create access to it so that the artifact can be pushed to it for the infrastructure to be deployed in all the target accounts. Please refer the following document for more information to accessing CodeCommit repository <https://docs.aws.amazon.com/codecommit/latest/userguide/setting-up.html>

Step 8: While at the root of the artifact, execute the git commands to clone the repository and then push the artifacts to the repository:

``` bash
git clone <git-url>
# add the artifacts contents
git add ./
git commit -m "<messsage> "
git push
```

Step 9: CodePipeline in the parent security account should started automatically and then CodeBuild in the next stage will start deploying to templates that deploys log archive setup and guardrails infrastructure in the target child accounts

## Troubleshooting

If the CodePipeline deployment fails at the CodeBuild stage, click on the details hyperlink on that particular stage and then you should be able to see the CodeBuild execution logs and noted down the account where the deployment failed to see the error

## important notes

### This solution will just deploy the solution in the provided account list. If the account number is removed from the list, it will not remove the deployed CloudFormation stack, which should be manually cleaned up if required

### For the first time deployment, this solution creates a new stack with the name provided in the .config files for each solution in the artifact package. In the next deployments, if the name is same, then the same stack will be updated only if there are changes (native nature of CloudFormation). In case if the stack name is changed, then it will attempt to create a new independent stack

© 2018 Amazon Web Services, Inc. or its affiliates. All Rights Reserved. This AWS Content is provided subject to the terms of the AWS Customer Agreement available at http://aws.amazon.com/agreement or other written agreement between Customer and Amazon Web Services, Inc.
