#!/bin/bash -e

region=$3
AWS_ACCOUNT=$(aws sts get-caller-identity --output text --query Account --profile $2)

echo "Deploying to Account ${AWS_ACCOUNT} in ${region}"

if [ -z "$1" ]; then
  echo "config file not supplied"
  exit 1
fi

# reading environment config file
echo "using config file: $1"
. $1

echo "Packaging the template and uploading the local artifacts to the ${pTemplateBucketName} S3 Bucket"
##Packaging the CloudFormation templates and uploading to S3 
aws cloudformation package --template-file ./parent-security-guardrails-setup.yaml --s3-bucket ${pTemplateBucketName} --output-template-file output-parent-security-guardrails-setup.yaml --profile $2

echo "Deploying the guardrails setup CloudFormation stack"
###Deploy Logging Setup in N Virginia Region
aws --region ${region} cloudformation deploy --stack-name ${pstackNameGuardrails} --template-file output-parent-security-guardrails-setup.yaml --parameter-overrides pNotifyEmail="$pNotifyEmail" pLoggingSetupStack="$pLoggingSetupStack" pS3LogsBucket="$pS3LogsBucket" pProfileLevel="$pProfileLevel" pRequiredTagKey="$pRequiredTagKey" pAllowUsersToChangePassword="$pAllowUsersToChangePassword" pHardExpiry="$pHardExpiry" pMaxPasswordAge="$pMaxPasswordAge" pMinimumPasswordLength="$pMinimumPasswordLength" pPasswordReusePrevention="$pPasswordReusePrevention" pRequireLowercaseCharacters="$pRequireLowercaseCharacters" pRequireNumbers="$pRequireNumbers" pRequireSymbols="$pRequireSymbols" pRequireUppercaseCharacters="$pRequireUppercaseCharacters" pLogsRetentionInDays="$pLogsRetentionInDays" --capabilities CAPABILITY_IAM --no-fail-on-empty-changeset --profile $2
